/*
** Module   : ColorPalette.java
** Abstract : Declares the supported terminal colors.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------Description-----------------
** 001 HC  20140119 Created initial version.
** 002 MAG 20140211 Map entries to AWT Color.
*/

package com.goldencode.p2j.ui;

import java.awt.Color;

/**
 * Set of supported terminal colors.
 * 
 * The implicit ordinal created by Java for this enum directly maps 
 * each enum "element" to the "COLOR_element" constant in NCurses/Curses. 
 * This mapping is implicitly utilized in NCurses/Curses drivers without 
 * any further translation. Other drivers will have to provide some kind 
 * of mapping from these values to their native rendering. 
 */
public enum ColorPalette
{
   BLACK(0, 0, 0), 
   RED(255, 0, 0), 
   GREEN(0, 255, 0), 
   YELLOW(255, 255, 0), 
   BLUE(0, 0, 255), 
   MAGENTA(255, 0, 255), 
   CYAN(0, 255, 255), 
   WHITE(255, 255, 255); 
   
   /** Corresponding AWT Color */
   private Color color;
   
   /**
    * Constructor.
    * 
    * @param   r
    *          Red component.
    * @param   g
    *          Green component.
    * @param   b
    *          Blue component
    */
   private ColorPalette(int r, int g, int b)
   {
      this.color = new Color(r, g, b);
   }
   
   /**
    * Get corresponding AWT Color.
    * 
    * @return  Corresponding AWT Color.
    */
   public Color getColor()
   {
      return color;
   }

   /**
    * Convert to a WEB color string.
    * 
    * @return  Corresponding WEB color string.
    */
   public String asWebColor()
   {
      return String.format("#%02x%02x%02x", 
                           color.getRed(), 
                           color.getGreen(), 
                           color.getBlue());
   }
}
